@@ -28,7 +28,7 @@ except ImportError:
 
 
 
-__version__='0.0.13'
+__version__='0.0.14'
 
 thrift_path = path.join(sys.modules["ROOT_DIR"], "qedata.thrift")
 thrift_path = path.abspath(thrift_path)
@@ -146,6 +146,9 @@ def auth(username, authcode):
 
 def login(username, password):
     asyncio.run(qedataClient.login(username, password))
+
+def check_auth():
+    return qedataClient.check_auth()
     
     
 def testClient():
